@@ -12,7 +12,7 @@ Modified from http://code.activestate.com/recipes/491261/
 """
 
 __author__ = "dbr/Ben"
-__version__ = "1.0"
+__version__ = "1.1"
 
 import os
 import time
@@ -158,10 +158,25 @@ class CachedResponse(StringIO.StringIO):
         """
         return self.url
 
+    def recache(self):
+        new_request = urllib2.urlopen(self.url)
+        set_cache_header = store_in_cache(
+            self.cache_location,
+            new_request.url,
+            new_request
+        )
+        CachedResponse.__init__(self, self.cache_location, self.url, True)
+
 
 if __name__ == "__main__":
     def main():
         """Quick test/example of CacheHandler"""
         opener = urllib2.build_opener(CacheHandler("/tmp/"))
-        print opener.open("http://google.com")
+        response = opener.open("http://google.com")
+        print response.headers
+        print "Response:", response.read()
+
+        response.recache()
+        print response.headers
+        print "After recache:", response.read()
     main()
